@@ -823,7 +823,7 @@ SavingsPlansPurchaseRecommendationTypeDef = TypedDict(
     "SavingsPlansPurchaseRecommendationTypeDef",
     {
         "AccountScope": Literal["PAYER", "LINKED"],
-        "SavingsPlansType": Literal["COMPUTE_SP", "EC2_INSTANCE_SP"],
+        "SavingsPlansType": Literal["COMPUTE_SP", "EC2_INSTANCE_SP", "SAGEMAKER_SP"],
         "TermInYears": Literal["ONE_YEAR", "THREE_YEARS"],
         "PaymentOption": Literal[
             "NO_UPFRONT",
